@@ -9,7 +9,6 @@ from pathlib import Path
 from typing import (
     Any,
     Callable,
-    Dict,
     Generator,
     Iterable,
     List,
@@ -18,149 +17,32 @@ from typing import (
     Tuple,
     TypeVar,
     Union,
+    cast,
 )
 
-from pydantic import Extra, PositiveInt, root_validator, validate_model, validator
+from pydantic import Extra, validate_model
 from pydantic.generics import GenericModel
+from rich import box
+from rich.columns import Columns
+from rich.console import Console, ConsoleOptions, Group, RenderableType, RenderResult
+from rich.panel import Panel
+from rich.text import Text
 
 from databooks.data_models.base import BaseCells, DatabooksBase
+from databooks.data_models.cell import CellMetadata, CodeCell, MarkdownCell, RawCell
 from databooks.logging import get_logger
 
 logger = get_logger(__file__)
 
-
-class NotebookMetadata(DatabooksBase):
-    """Notebook metadata. Empty by default but can accept extra fields."""
-
-
-class CellMetadata(DatabooksBase):
-    """Cell metadata. Empty by default but can accept extra fields."""
-
-
-class Cell(DatabooksBase):
-    """
-    Jupyter notebook cells.
-
-    Fields `outputs` and `execution_count` are not included since they should only be
-     present in code cells - thus are treated as extra fields.
-    """
-
-    metadata: CellMetadata
-    source: Union[List[str], str]
-    cell_type: str
-
-    def __hash__(self) -> int:
-        """Cells must be hashable for `difflib.SequenceMatcher`."""
-        return hash(
-            (type(self),) + tuple(v) if isinstance(v, list) else v
-            for v in self.__dict__.values()
-        )
-
-    def remove_fields(
-        self, fields: Iterable[str] = (), missing_ok: bool = True, **kwargs: Any
-    ) -> None:
-        """
-        Remove Cell fields.
-
-        Similar to `databooks.data_models.base.remove_fields`, but will ignore required
-         fields for `databooks.data_models.notebook.Cell`.
-        """
-        # Ignore required `Cell` fields
-        cell_fields = self.__fields__  # required fields especified in class definition
-        if any(field in fields for field in cell_fields):
-            logger.debug(
-                "Ignoring removal of required fields "
-                + str([f for f in fields if f in cell_fields])
-                + f" in `{type(self).__name__}`."
-            )
-            fields = [f for f in fields if f not in cell_fields]
-
-        super(Cell, self).remove_fields(fields, missing_ok=missing_ok)
-
-        if self.cell_type == "code":
-            self.outputs: List[Dict[str, Any]] = (
-                [] if "outputs" not in dict(self) else self.outputs
-            )
-            self.execution_count: Optional[PositiveInt] = (
-                None if "execution_count" not in dict(self) else self.execution_count
-            )
-
-    def clear_fields(
-        self,
-        *,
-        cell_metadata_keep: Sequence[str] = None,
-        cell_metadata_remove: Sequence[str] = None,
-        cell_remove_fields: Sequence[str] = (),
-    ) -> None:
-        """
-        Clear cell metadata, execution count, outputs or other desired fields (id, ...).
-
-        You can also specify metadata to keep or remove from the `metadata` property of
-         `databooks.data_models.notebook.Cell`.
-        :param cell_metadata_keep: Metadata values to keep - simply pass an empty
-         sequence (i.e.: `()`) to remove all extra fields.
-        :param cell_metadata_remove: Metadata values to remove
-        :param cell_remove_fields: Fields to remove from cell
-        :return:
-        """
-        nargs = sum((cell_metadata_keep is not None, cell_metadata_remove is not None))
-        if nargs != 1:
-            raise ValueError(
-                "Exactly one of `cell_metadata_keep` or `cell_metadata_remove` must"
-                f" be passed, got {nargs} arguments."
-            )
-
-        if cell_metadata_keep is not None:
-            cell_metadata_remove = tuple(
-                field for field, _ in self.metadata if field not in cell_metadata_keep
-            )
-        self.metadata.remove_fields(cell_metadata_remove)  # type: ignore
-
-        self.remove_fields(fields=cell_remove_fields, missing_ok=True)
-
-    @validator("cell_type")
-    def cell_has_valid_type(cls, v: str) -> str:
-        """Check if cell has one of the three predefined types."""
-        valid_cell_types = ("raw", "markdown", "code")
-        if v not in valid_cell_types:
-            raise ValueError(f"Invalid cell type. Must be one of {valid_cell_types}")
-        return v
-
-    @root_validator
-    def code_cell_has_valid_outputs(cls, values: Dict[str, Any]) -> Dict[str, Any]:
-        """Check that code cells have list-type outputs."""
-        if values.get("cell_type") == "code" and "outputs" not in values:
-            raise ValueError(
-                f"All code cells must have an `outputs` property, got {values}"
-            )
-            if not isinstance(values["outputs"], list):
-                raise ValueError(
-                    f"Cell outputs must be a list, got {type(values['outputs'])}"
-                )
-        return values
-
-    @root_validator
-    def only_code_cells_have_outputs_and_execution_count(
-        cls, values: Dict[str, Any]
-    ) -> Dict[str, Any]:
-        """Check that only code cells have outputs and execution count."""
-        if values.get("cell_type") != "code" and (
-            ("outputs" in values) or ("execution_count" in values)
-        ):
-            raise ValueError(
-                "Found `outputs` or `execution_count` for cell of type"
-                f" `{values['cell_type']}`"
-            )
-        return values
-
-
-T = TypeVar("T", Cell, Tuple[List[Cell], List[Cell]])
+Cell = Union[CodeCell, RawCell, MarkdownCell]
+CellsPair = Tuple[List[Cell], List[Cell]]
+T = TypeVar("T", Cell, CellsPair)
 
 
 class Cells(GenericModel, BaseCells[T]):
     """Similar to `list`, with `-` operator using `difflib.SequenceMatcher`."""
 
-    __root__: Sequence[T] = []
+    __root__: Sequence[T] = ()
 
     def __init__(self, elements: Sequence[T] = ()) -> None:
         """Allow passing data as a positional argument when instantiating class."""
@@ -175,9 +57,7 @@ class Cells(GenericModel, BaseCells[T]):
         """Use list property as iterable."""
         return (el for el in self.data)
 
-    def __sub__(
-        self: Cells[Cell], other: Cells[Cell]
-    ) -> Cells[Tuple[List[Cell], List[Cell]]]:
+    def __sub__(self: Cells[Cell], other: Cells[Cell]) -> Cells[CellsPair]:
         """Return the difference using `difflib.SequenceMatcher`."""
         if type(self) != type(other):
             raise TypeError(
@@ -201,7 +81,7 @@ class Cells(GenericModel, BaseCells[T]):
                 f" {n_context} for {len(self)} and {len(other)} cells in"
                 " notebooks."
             )
-        return Cells[Tuple[List[Cell], List[Cell]]](
+        return Cells[CellsPair](
             [
                 # https://github.com/python/mypy/issues/9459
                 tuple((self.data[i1:j1], other.data[i2:j2]))  # type: ignore
@@ -209,6 +89,23 @@ class Cells(GenericModel, BaseCells[T]):
             ]
         )
 
+    def __rich_console__(
+        self, console: Console, options: ConsoleOptions
+    ) -> RenderResult:
+        """Rich display of all cells in notebook."""
+        yield from self._get_renderables(expand=True, width=options.max_width // 3)
+
+    def _get_renderables(self, **wrap_cols_kwargs: Any) -> Iterable[RenderableType]:
+        """Get the Rich renderables, depending on whether `Cells` is a diff or not."""
+        if all(isinstance(el, tuple) for el in self.data):
+            return chain.from_iterable(
+                Cells.wrap_cols(val[0], val[1], **wrap_cols_kwargs)
+                if val[0] != val[1]
+                else val[0]
+                for val in cast(List[CellsPair], self.data)
+            )
+        return cast(List[Cell], self.data)
+
     @classmethod
     def __get_validators__(cls) -> Generator[Callable[..., Any], None, None]:
         """Get validators for custom class."""
@@ -222,42 +119,46 @@ class Cells(GenericModel, BaseCells[T]):
         else:
             return v
 
+    @classmethod
+    def wrap_cols(
+        cls, first_cells: List[Cell], last_cells: List[Cell], **cols_kwargs: Any
+    ) -> Sequence[Columns]:
+        """Wrap the first and second cells into colunmns for iterable."""
+        _empty = [Panel(Text("<None>", justify="center"), box=box.SIMPLE)]
+        _first = Group(*first_cells or _empty)
+        _last = Group(*last_cells or _empty)
+        return [Columns([_first, _last], **cols_kwargs)]
+
     @staticmethod
     def wrap_git(
         first_cells: List[Cell],
         last_cells: List[Cell],
         hash_first: Optional[str] = None,
         hash_last: Optional[str] = None,
-    ) -> List[Cell]:
+    ) -> Sequence[Cell]:
         """Wrap git-diff cells in existing notebook."""
-        return (
-            [
-                Cell(
-                    metadata=CellMetadata(git_hash=hash_first),
-                    source=[f"`<<<<<<< {hash_first}`"],
-                    cell_type="markdown",
-                )
-            ]
-            + first_cells
-            + [
-                Cell(
-                    source=["`=======`"],
-                    cell_type="markdown",
-                    metadata=CellMetadata(),
-                )
-            ]
-            + last_cells
-            + [
-                Cell(
-                    metadata=CellMetadata(git_hash=hash_last),
-                    source=[f"`>>>>>>> {hash_last}`"],
-                    cell_type="markdown",
-                )
-            ]
-        )
+        return [
+            MarkdownCell(
+                metadata=CellMetadata(git_hash=hash_first),
+                source=[f"`<<<<<<< {hash_first}`"],
+                cell_type="markdown",
+            ),
+            *first_cells,
+            MarkdownCell(
+                source=["`=======`"],
+                cell_type="markdown",
+                metadata=CellMetadata(),
+            ),
+            *last_cells,
+            MarkdownCell(
+                metadata=CellMetadata(git_hash=hash_last),
+                source=[f"`>>>>>>> {hash_last}`"],
+                cell_type="markdown",
+            ),
+        ]
 
     def resolve(
-        self: Cells[Tuple[List[Cell], List[Cell]]],
+        self: Cells[CellsPair],
         *,
         keep_first_cells: Optional[bool] = None,
         first_id: Optional[str] = None,
@@ -294,6 +195,10 @@ class Cells(GenericModel, BaseCells[T]):
         )
 
 
+class NotebookMetadata(DatabooksBase):
+    """Notebook metadata. Empty by default but can accept extra fields."""
+
+
 class JupyterNotebook(DatabooksBase, extra=Extra.forbid):
     """Jupyter notebook. Extra fields yield invalid notebook."""
 
@@ -302,6 +207,21 @@ class JupyterNotebook(DatabooksBase, extra=Extra.forbid):
     metadata: NotebookMetadata
     cells: Cells[Cell]
 
+    def __rich__(self) -> RenderResult:
+        """Rich display notebook."""
+        kernelspec = self.metadata.dict().get("kernelspec", {})
+        # Check if this is a `DiffCells`
+        if isinstance(kernelspec, tuple):
+            first, last = (ks.get("language", "text") for ks in kernelspec)
+            nb_lang = first if first == last else "text"
+        else:
+            nb_lang = kernelspec.get("language", "text")
+
+        for cell in self.cells:
+            if isinstance(cell, CodeCell):
+                cell.metadata = CellMetadata(**cell.metadata.dict(), lang=nb_lang)
+        return self.cells
+
     @classmethod
     def parse_file(cls, path: Path | str, **parse_kwargs: Any) -> JupyterNotebook:
         """Parse notebook from a path."""
@@ -345,7 +265,7 @@ class JupyterNotebook(DatabooksBase, extra=Extra.forbid):
          sequence (i.e.: `()`) to remove all extra fields.
         :param notebook_metadata_remove: Metadata values to remove
         :param cell_kwargs: keyword arguments to be passed to each cell's
-         `databooks.data_models.Cell.clear_metadata`
+         `databooks.data_models.cell.BaseCell.clear_metadata`
         :return:
         """
         nargs = sum(
