@@ -21,7 +21,8 @@ def get_logger(name: str) -> logging.Logger:
 def set_verbose(logger: logging.Logger) -> None:
     """Set logger to DEBUG level when user requests verbosity."""
     verbose_level = logging.DEBUG
-    logger.setLevel(verbose_level)
-    logger.debug(
-        f"Verbose mode: setting log level to {logging.getLevelName(verbose_level)}"
-    )
+    if logger.level < verbose_level:
+        logger.setLevel(logging.DEBUG)
+        logger.debug(
+            f"Verbose mode: setting log level to {logging.getLevelName(verbose_level)}"
+        )
